@@ -90,6 +90,7 @@ status progStatus = {
 	false,			// arq_shown;
 	false,			// UI_expert;
 	false,			// UI_default;
+
 	0,				// int arq_notify_timeout
 	false			// bool notify_receipt
 };
@@ -224,13 +225,15 @@ void status::loadLastState()
 		flmsgpref.get("myemail", defbuffer, "");
 		my_email = defbuffer; free(defbuffer);
 
-		if (flmsgpref.get("sernbr", defbuffer, ""))
+		if (flmsgpref.get("sernbr", defbuffer, "")) {
 			sernbr = defbuffer;
-		free(defbuffer);
+		    free(defbuffer);
+        }
 
-		if (flmsgpref.get("rgnbr", defbuffer, ""))
+		if (flmsgpref.get("rgnbr", defbuffer, "")) {
 			rgnbr = defbuffer;
-		free(defbuffer);
+		    free(defbuffer);
+        }
 
 		if (flmsgpref.get("rri", i, rri)) rri = i;
 
