@@ -3,24 +3,23 @@
 //
 // Copyright (C) 2008
 //              Stelios Bounanos, M0GLD
-// ----------------------------------------------------------------------------
-// Copyright (C) 2014
-//              David Freese, W1HKJ
 //
-// This file is part of flmsg
+// This file is part of flmsg.
 //
-// flrig is free software; you can redistribute it and/or modify
+// This is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
-// flrig is distributed in the hope that it will be useful,
+// This software is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
+// =====================================================================
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -47,6 +46,8 @@
 
 using namespace std;
 
+namespace icons {
+
 #if USE_IMAGE_LABELS
 typedef map<Fl_Multi_Label*, Fl_Image**> imap_t;
 static imap_t* imap = 0;
@@ -81,7 +82,7 @@ const char* make_icon_label(const char* text, const char** pixmap)
 	Fl_Image** images = new Fl_Image*[2];
 	images[0] = new Fl_Pixmap(pixmap ? pixmap : clear_row_icon);
 	images[1] = 0; // we create this on demand
-	// set_icon_label_ will set mlabel->labela later
+				   // set_icon_label_ will set mlabel->labela later
 	mlabel->typea = _FL_IMAGE_LABEL;
 
 	if (!text)
@@ -260,3 +261,5 @@ void set_message_icon(const char** pixmap)
 	msg->box(FL_NO_BOX);
 	msg->image(msg_icon = new Fl_Pixmap(pixmap));
 }
+
+} // icons
